@@ -2,6 +2,7 @@
 # See also LICENSE.txt
 
 import ConfigParser
+import glob
 import os
 import zest.releaser.utils
 
@@ -12,10 +13,8 @@ def upload(context):
         return
     if not zest.releaser.utils.ask('Upload to %s' % destination):
         return
-
-    tarball = '%s-%s.tar.gz' % (context['name'], context['version'])
-    src = os.path.join(context['tagdir'], 'dist', tarball)
-    os.system(' '.join(['scp', src, destination]))
+    sources = glob.glob(os.path.join(context['tagdir'], 'dist', '*'))
+    os.system(' '.join(['scp'] + sources + [destination]))
 
 
 def read_configuration():
